<h1 align="center" id="title">DOK2ANY</h1>

<p id="description">Dok2any is a Python package designed to convert dok files generated by LeDock molecular docking software, a non-standard chemical structure file format unique for LeDock, to various other chemical structure formats using Openbabel.</p>

<h2>Installation Steps:</h2>

<p>Install the package using pip:</p>

<pre><code>pip install dok2any
</code></pre>

<h2>Dependencies:</h2>

<ul>
    <li>python (>= 3.10)</li>
    <li>openbabel-wheel</li>
</ul>

<h2>Usage:</h2>

<p>The dok2any package provides a command-line script to perform DOK file conversions.</p>

<pre><code>usage: dok2any [-h] -idok IDOK -oformat OFORMAT -odir ODIR

Convert DOK files to specified output format using Open Babel.

arguments:
  -h, --help                 show this help message and exit
  -idok IDOK, --idok IDOK    Path to the folder containing DOK files (required)
  -oformat OFORMAT, --oformat OFORMAT  Output format for conversion (e.g., mol2, pdb, sdf) (required)
  -odir ODIR, --odir ODIR    Path to the output directory (required)
</code></pre>

<h3>Example Usage:</h3>

convert all the DOK files containing in a folder:
<pre><code>dok2any -idok data/dok_files/ -oformat sdf -odir data/converted_files/
</code></pre>
<p>This command will convert all DOK files in the <code>data/dok_files/</code> folder to SDF format and save the output files in the <code>data/converted_files</code> directory.</p>

convert a single DOK file:
<pre><code>dok2any -idok data/dok_files/ligand01.dok -oformat mol2 -odir data/converted_files/
</code></pre>
<p>This command will convert ligand01.dok file in the <code>data/dok_files/</code> folder to MOL2 format and save the output files in the <code>data/converted_files</code> directory.</p>

<h2>License:</h2>

<p>dok2any is licensed under the MIT License. See the <a href="LICENSE">LICENSE</a> file for more information.</p>


